cumulusci.salesforce\_api package
=================================

Subpackages
-----------

.. toctree::

   cumulusci.salesforce_api.tests

Submodules
----------


.. automodule:: cumulusci.salesforce_api.exceptions
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.salesforce_api.metadata
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.salesforce_api.package_zip
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.salesforce_api.soap_envelopes
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.salesforce_api.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.salesforce_api
   :members:
   :undoc-members:
   :show-inheritance:
